@@ -7,7 +7,7 @@ import numpy as np
 
 class PhaseNet(WaveformModel):
     def __init__(
-        self, in_channels=3, classes=3, phases=None, sampling_rate=100, **kwargs
+        self, in_channels=3, classes=3, phases="NPS", sampling_rate=100, **kwargs
     ):
         citation = (
             "Zhu, W., & Beroza, G. C. (2019). "
@@ -127,3 +127,23 @@ class PhaseNet(WaveformModel):
             )
 
         return sorted(picks)
+
+    def get_model_args(self):
+        model_args = super().get_model_args()
+        for key in [
+            "citation",
+            "in_samples",
+            "output_type",
+            "default_args",
+            "pred_sample",
+            "labels",
+            "sampling_rate",
+        ]:
+            del model_args[key]
+
+        model_args["in_channels"] = self.in_channels
+        model_args["classes"] = self.classes
+        model_args["phases"] = self.labels
+        model_args["sampling_rate"] = self.sampling_rate
+
+        return model_args
